@@ -32,7 +32,8 @@ def preprocessing_predictions(df, imputer, mapping_dicts: dict, config: dict, tr
           .pipe(DEutils.impute_nas,
                 columns_to_impute=config['impute_columns'],
                 imp=imputer)
-          .pipe(DEutils.log_transformation, columns=config['cols_to_transform'])
+          .pipe(DEutils.log_transformation,
+                columns=config['cols_to_transform'])
           .pipe(DEutils.map_conv_prob_using_dictionary,
                 mapping_dicts,
                 'MXType')
@@ -47,7 +48,8 @@ def preprocessing_predictions(df, imputer, mapping_dicts: dict, config: dict, tr
                 'PreviousContacts',
                 drop=True,
                 )
-          .pipe(DEutils.drop_columns, columns=config['cols_to_drop'])
+          .pipe(DEutils.drop_columns,
+                columns=config['cols_to_drop'])
           .pipe(utils.reduce_mem_usage_category)
           .pipe(DEutils.one_hot_encoding)
           .pipe(DEutils.align_dataframe_with_sample,
