@@ -133,6 +133,22 @@ def one_hot_encoding(df):
 
 
 def align_dataframe_with_sample(df, sample, fillvalue=0, predictions_flag=None):
+    """
+    This function aligns a dataframe with a given sample.
+    - Why do we align? A model expects a matrix of numbers, where each row is a record and each column is a feature.
+        The model won't look at the column names of the dataframe, it just takes information and produces an outputs; if
+        we set as input a dataframe with a greater number of  columns, it will throw an error. Or worse, if we set as
+        input a dataframe with the same number of columns but in different order, there will be no error but the output
+        will be wrong!! is then VERY important to give the same columns (and in the same order!) to the batch transform
+         that we had during the training of the model.
+    Args:
+        df: Dataframe to align
+        sample: Sample of the dataframe used in training
+        fillvalue: If the column doesn't exist in df but exists in the sample, this value will fill the cells.
+        predictions_flag: In the case of prediction, we must preserve IDLead and IDcampaign.
+
+    Returns: Aligned dataframe
+    """
     if predictions_flag is None:
         logger.info('aligning dataframe with sample')
         _, df = sample.align(
@@ -143,6 +159,7 @@ def align_dataframe_with_sample(df, sample, fillvalue=0, predictions_flag=None):
     else:
         idlead_col = df['idLead']
         idcampaign_col = df['idCampaign']
+
         logger.info('aligning dataframe with sample')
         _, df = sample.align(
             df,
@@ -240,7 +257,16 @@ def fill_na_with_unknown(df, columns):
 
 
 def correct_C80_success_code(df):
-    # C80 has an special conversion Status, setting it to 14 like the other campaigns
+    """
+    C80 has an special conversion Status, setting it to 14 like the other campaigns
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: corrected dataframe
+
+    """
+
 
     # Correcting non perfect conversions
     df.loc[(df['idCampaign'] == 80) &
@@ -259,6 +285,14 @@ def correct_C80_success_code(df):
 
 
 def set_idemailstatus_target_column(df):
+    """
+    Sets the target column for the probability model, (Conversion =1 and Non-conversion =0)
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: Dataframe with target column for probability model ready to use.
+    """
     if ('IDEmailStatus' in df.columns):
         logger.info('Setting E-Mail status target ')
         df = df[~df['IDEmailStatus'].isin([3, 5, 7, 32])]
@@ -283,6 +317,14 @@ def set_idemailstatus_target_column(df):
 
 
 def set_bv_target_column(df):
+    """
+    Sets the target column for the bv model,
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: Dataframe with target column for bv model ready to use.
+    """
     if ('BV' in df.columns):
         logger.info('Setting BV status target ')
         df = df[df.BV.notna()]
@@ -318,19 +360,17 @@ def set_bv_fake_column(df):
     return df
 
 
-def set_bv_discrete_target_column(df, bins):
-    if ('BV' in df.columns):
-        logger.info('Setting BV status target for classification ')
-        df.BV.fillna(value=0, inplace=True)
-        labels = [0, 1, 2, 3, 4, 5]
-        df.insert(loc=1, column='BV_cut', value=pd.cut(x=df['BV'], bins=bins, labels=labels).astype('float32'))
-    else:
-        logger.error('No BV column found')
-        raise Exception('No BV column found!!!!!')
-    return df
-
-
 def set_target_column(df, model_type):
+    """
+    Sets target column in order to train a model, based on parametrizatikon of the training job
+    Args:
+        df: input dataframe
+        model_type: Could be Probability, bv or bvfake;
+
+    Returns:
+        df: Dataframe with target column
+
+    """
     if model_type == 'probability':
         df = set_idemailstatus_target_column(df=df)
     elif model_type == 'bv':
@@ -367,6 +407,15 @@ def create_company_years_column(df):
 
 
 def clean_companytype(df):
+    """
+    Solves some errors in the company type of the data
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: Dataframe with corrected company types
+
+    """
     df.loc[
         (df['Type'] != 'Educational Institution') &
         (df['Type'] != 'Government Agency') &
@@ -398,32 +447,32 @@ def fill_seniority_column(df):
 
 
 def filter_countries(df):
+    """
+    Some campaigns have to many countries, we pick the 8 more common to add to the model
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: Dataframe with corrected countries
+
+    """
     logger.info(f'countries out of top 8 go to other')
     top = df['Country'].value_counts().head(8).index.tolist()
     df.loc[~df['Country'].isin(top), 'Country'] = 'other'
     return df
 
 
-def process_bulkstatus(df):
-    logger.info("Processing Bulk Status column")
-    if 'BulkStatus' in df:
-        logger.info(f"{df['BulkStatus'].value_counts()}")
-        df['is_OOO'] = 0
-        df.loc[(df['BulkStatus'] == 6), 'is_OOO'] = 1
-        df['is_NN'] = 0
-        df.loc[(df['BulkStatus'] == 12), 'is_NN'] = 1
-        df.drop(labels=['BulkStatus'], axis=1, inplace=True)
-        logger.info('Deleted BulkStatus column')
-        logger.info('OOO')
-        logger.info(df['is_OOO'].value_counts())
-        logger.info('NN')
-        logger.info(df['is_NN'].value_counts())
-    else:
-        logger.info('Column not present')
-    return df
-
-
 def impute_growth(df):
+    """
+    There are some NANs in the growth columns, we use a very simple linear extrapolation to fill some of those missing
+    values.
+    Args:
+        df: input dataframe
+
+    Returns:
+        df: dataframe with less NANs in growth columns.
+
+    """
     logger.info("Applying growth imputation")
     df['Growth12M'] = df['Growth12M'].fillna(df['Growth6M'] * 2)
     df['Growth6M'] = df['Growth6M'].fillna(df['Growth3M'] * 2)
@@ -647,7 +696,6 @@ def clean_mxtype_using_dictionary(df, mx_bv_dict, mx_prob_dict):
 
 def map_conv_prob_using_dictionary(df, mapping_dicts, column: str, drop: bool = True):
     """
-
     :param df: Input Dataset
     :param mx_bv_dict: MXTypes dictionary by bv performance
     :param mx_prob_dict: MXTypes dictionary by prob performance
